#
# spec file for package mp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mp
Version:        5.2.13
Release:        3.4
Summary:        A text editor for programmers
License:        GPL-2.0-only
URL:            https://triptico.com/software/mp.html
Source0:        mp-%{version}.tar.gz
Source1:        mp-%{version}.tar.gz.asc
Source2:        %{name}.keyring
Source3:        %{name}-5.desktop
Source4:        %{name}-5.png
Source5:        %{name}-rpmlintrc
Source6:        %{name}-5-gtk3.desktop
Patch0:         %{name}-docdir.patch
Patch1:         %{name}-scrollevent.patch
BuildRequires:  fdupes
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(gtk+-3.0)

%description
Minimum Profit
A text editor for programmers

Features

    * Fully scriptable using a C-like scripting language.
    * Unlimited undo levels.
    * Complete Unicode support.
    * Multiple files can be edited at the same time and blocks copied and pasted among them.
    * Syntax highlighting for many popular languages / file formats: C, C++, Perl, Shell Scripts,
      Ruby, Php, Python, HTML...
    * Creative use of tags: tags created by the external utility ctags are used to move
      instantaneously to functions or variables inside your current source tree. Tags are
      visually highlighted (underlined), and symbol completion can be triggered to avoid typing
      your own function names over and over.
    * Intelligent help system: pressing F1 over any word of a text being edited triggers the
      underlying system help (calling man when editing C or Shell files, perldoc with Perl, ri
      on Ruby, winhelp on MS Windows...).
    * Understandable interface: drop-down menus, reasonable default key bindings.
    * Configurable keys, menus and colors.
    * Text templates can be easily defined / accessed.
    * Multiplatform: Console/curses, GTK+, MS Windows.
    * Automatic indentation, word wrapping, internal grep, learning / repeating functions.
    * Spellchecking support (via the ispell package).
    * Multilingual.
    * Password-protected, encrypted text files (using the ARCFOUR algorithm).
    * It helps you abandon vi, emacs and other six-legged freaks definitely.

%package        gtk3
Summary:        A text editor for programmers (GTK+3 version)
Requires:       %{name} = %{version}

%description    gtk3
Minimum Profit
A text editor for programmers (GTK+3 version)

Features

    * Fully scriptable using a C-like scripting language.
    * Unlimited undo levels.
    * Complete Unicode support.
    * Multiple files can be edited at the same time and blocks copied and pasted among them.
    * Syntax highlighting for many popular languages / file formats: C, C++, Perl, Shell Scripts,
      Ruby, Php, Python, HTML...
    * Creative use of tags: tags created by the external utility ctags are used to move
      instantaneously to functions or variables inside your current source tree. Tags are
      visually highlighted (underlined), and symbol completion can be triggered to avoid typing
      your own function names over and over.
    * Intelligent help system: pressing F1 over any word of a text being edited triggers the
      underlying system help (calling man when editing C or Shell files, perldoc with Perl, ri
      on Ruby, winhelp on MS Windows...).
    * Understandable interface: drop-down menus, reasonable default key bindings.
    * Configurable keys, menus and colors.
    * Text templates can be easily defined / accessed.
    * Multiplatform: Console/curses, GTK+, MS Windows.
    * Automatic indentation, word wrapping, internal grep, learning / repeating functions.
    * Spellchecking support (via the ispell package).
    * Multilingual.
    * Password-protected, encrypted text files (using the ARCFOUR algorithm).
    * It helps you abandon vi, emacs and other six-legged freaks definitely.

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags}"
./config.sh --prefix=%{_prefix} --docdir=%{_docdir}/mp-5
%make_build
mv mp-5 mp-5-qt5
WITHOUT_QT5=1 WITHOUT_QT4=1 ./config.sh --prefix=%{_prefix} --docdir=%{_docdir}/mp-5
%make_build
mv mp-5 mp-5-gtk3
mv mp-5-qt5 mp-5

%install
%make_install

install -D -p -m 644 %{SOURCE3} %{buildroot}/%{_datadir}/applications/%{name}-5.desktop
install -D -p -m 644 %{SOURCE4} %{buildroot}/%{_datadir}/pixmaps/%{name}-5.png
install -p -m 644 %{SOURCE6} %{buildroot}/%{_datadir}/applications/%{name}-5-gtk3.desktop
install -m 755 mp-5-gtk3 %{buildroot}%{_bindir}/mp-5-gtk3
install -m 644 mp-5.1 %{buildroot}/%{_mandir}/man1/mp-5-gtk3.1

%suse_update_desktop_file %{name}-5 TextEditor

%find_lang minimum-profit
rm %{buildroot}%{_docdir}/mp-5/mpsl_quickref.ps
%fdupes -s %{buildroot}

%files -f minimum-profit.lang
%{_bindir}/%{name}-5
%{_bindir}/%{name}sl
%dir %{_docdir}/%{name}-5
%{_docdir}/%{name}-5/*
%{_mandir}/man1/%{name}-5.1%{?ext_man}
%dir %{_datadir}/%{name}-5
%{_datadir}/%{name}-5/*
%{_datadir}/applications/%{name}-5.desktop
%{_datadir}/pixmaps/%{name}-5.png

%files gtk3
%{_bindir}/%{name}-5-gtk3
%{_datadir}/applications/%{name}-5-gtk3.desktop
%{_mandir}/man1/%{name}-5-gtk3.1%{?ext_man}

%changelog
* Wed Dec  4 2024 Martin Pluskal <mpluskal@suse.com>
- Modernise spec file and remove obsolete rpmlintrc filters
- Do not use source urls for download as they are not available
  anymore
* Tue Dec  3 2024 Friedrich Haubensak <hsk17@mail.de>
- Add mp-scrollevent.patch to fix type issue found by gcc14 compile
  time error.
* Thu Feb 22 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Mon Feb 26 2018 aloisio@gmx.com
- Update to version 5.2.13
  New features:
  * This release includes Qt5 support.
  version 5.2.12
  New features:
  * This version includes a new driver for raw ANSI terminals,
    for systems who don't (want to) have libncursesw.
  * The cursor position for every file is remembered from
    session to session.
  Fixed bugs:
  * Fixed action `open_under_cursor' (again).
  * Fixed behaviour inconsistency between actions `seek' and
    `seek-next'.
  * Fixed action `sync' (save all modified files).
  Other features:
  * Version numbering convention has changed: development
    versions shall no longer have (CURRENTVERSION+1)-dev,
    but (CURRENTVERSION)-patch.
  version 5.2.11
  This version includes the following lot of features by
  fellow developer X-Ryl669:
  * New cut line action (copy and delete line), bound by
    default to ctrl-k.
  * New key assignation to document list (ctrl-e).
  * Fix ncurses detection for recent distributions.
  * Added suspension (bound to ctrl-l) for curses driver.
  * Added word selection with mouse double-click.
  * Paste in ncurses prompt.
  * New seek matching brace feature, bound to ctrl-j.
  * Text search wraps to the top of the document as many
    other text editors do.
  * Several miscellaneous fixes.
  Other features:
  * Window position and size is saved in all GUI interfaces.
- Switched build to Qt5 and GTK+3
- Split gtk3 executable into subpackage
- Added mp-5-gtk3.desktop as source
* Mon Jan 16 2017 mpluskal@suse.com
- Cleanup spec file
- Add gpg signature
* Mon Jan 16 2017 aloisio@gmx.com
- Update to version 5.2.10
  New features:
  * New configuration directive mp.config.show_line_numbers,
    to show line numbers to the left of each line.
  5.2.9
  New features:
  * New configuration directive mp.config.emacs_scrolling, to
    enable/disable emacs-like scrolling (half screen jumps
    instead of line-by-line).
  * New actions `scroll_up' and `scroll_down', bound by
    default to `alt-cursor-up' and `alt-cursor-down'.
  * New syntax highlight for JSON files.
  5.2.8
  New features:
  * Mouse support on text interfaces (it can be disabled by
    setting mp.config.no_text_mouse to 1).
  * Support for the MS Windows console. Two win32 binaries are
    now deployed: the classic, windowed mp-5.exe and the new,
    console-based, mp-5c.exe.
  * Added column to action `grep'.
  5.2.7
  New features:
  * File format dependent build targets (to be used if a Makefile
    is not found in the current directory).
  * `open_under_cursor' also works over diff file marks (those
    starting with @@).
  * New configuration directive `make_opts', for command line
    options to be added to `make'.
  * Search and replace accepts Unicode chars in \x{HHHH} format.
  * The status line format string can also include the %%u token
    to show the Unicode codepoint of the character under the cursor.
  Fixed bugs:
  * Fixed hexdump search.
  * Avoid having zero-size marks.
  5.2.6
  * Fixed grep.
  5.2.5
  New features:
  * Hex view is searchable.
  * New syntax highlight for JavaScript.
  Fixed bugs:
  * Avoid crashes in `play_macro' action.
  * Fixed failing menus on Qt4.
  * Fixed file renaming errors in the directory editor.
  Important changes:
  * Default tab settings has been changed to convert to 4 spaces.
  5.2.4
  New features:
  * A new directory editor, linked to the new `open_folder'
    action, that allows file deletion and renaming.
  * New configuration directive `font_weight'.
  * New action `insert_time_stamp', that inserts the current
    timestamp according to the format in the
    `mp.config.time_stamp_format' configuration directive.
  Changes:
  * mp.add_keyseq() has been reimplemented and no longer needs
    the initial [, as it already assumes it's used only for ANSI
    sequences (so you may need to tweak your own definitions).
  Fixes:
  * Dynamic tab tweking.
  * Avoid hangups when trying to highlight 0 size regexes.
  * Minor VCS fixes.
  * Revert can be undone.
  5.2.3
  New improvements:
  * New actions `move_section_up' and `move_section_down'
    (bound by default to `alt-cursor-up' and `alt-cursor-down').
  * VCS commands can have a common or private log.
  * The menu has been reorganized.
  * Keycode targets can also be other keycodes (not only editor
    actions), so they can be used as aliases.
  * Encodings are now selected from a list.
  * The Curses interface now includes a read-only scrollbar.
  * A much faster hexadecimal viewer.
  Other changes:
  * Al MP code has been refactored to use new MPSL object-oriented
    capabilities.
  5.2.2
  Major improvements:
  * Added Version Control commands (bound by default to `ctrl-p').
    The supported systems are (adding new ones is very easy):
    + Git
    + Subversion
    + Mercurial
  * If any file being edited is modified externally, the situation
    is detected and the user is prompted for file reloading.
  * GTK library detection: Uses 3.x if available, then 2.x.
  * Special information gathering on help: if the file being edited
    is C/C++ and asking for help (by pressing `F1') do not return
    a `man' page, a special routine inspects all source files and
    headers looking for structures, variables and function prototypes
    to be shown as help.
  * If a template name starts with #!, the template body is assumed
    to be MPSL code, that will be executed and its value returned
    as the template to be inserted.
  * New "Pipes" game.
  * New `check_for_updates' action.
  Fixed bugs:
  * Make `keep_eol' behaviour more intuitive (bug #1294).
  5.2.1
  New actions:
  * `indent_block': Indents the current line or the selected block.
  * `unindent_block': Reverse of `indent_block'.
  New features:
  * ~/.mp_templates can be a directory. If it is, the `global' file
    there is always read (and those templates put at the top) and it
    will also read a file named like the current syntax highlight
    definition (so different templates appear if your editing C, Perl,
    etc.).
  New configuration options:
  * `mp.config.smart_bol': if set to nonzero, the `move_bol' action
    now moves to the first non-blank character in the line instead of
    to column 0 (unless the cursor is already on the first non-blank).
  Other improvements:
  * The following actions accept additional arguments when called
    as functions (and do not ask for them, if present):
    + `goto'
    + `save_as'
    + `exec_command'
    + `filter_selection'
- Refreshed mp-docdir.patch
- Added mp-rpmlintrc
- Spec cleanup
* Sat Apr 23 2011 detlef@links2linux.de
- new upstream version <5.2.0>
  * New actions:
  - filter_selection: to filter the selection (or the full document if no
    selection is done) through a system command.
  - exec_action: that shows a list of actions to execute on the current
    document.
  - cut_lines_with_string: that cuts to the clipboard all lines in a document
    or block that matches a regular expression.
  - insert_real_tab: bound to shift-tab, to insert a tab character (\t)
    regardless of whatever is set in the tabs_as_spaces configuration variable.
  - insert_next_item: to insert a new enumeration item in a document.
  * Bugfixes:
  - Fixed insert / overwrite mode.
  - If a selection is invisible (incomplete or with the start and end in the
    same character), a new keystroke does not jump to it.
  * New configuration options:
  - mp.config.hw_cursor: to activate the hardware cursor in text environments
    (disabled by default).
  * Text user interface improvements:
  - File opening list is fully navegable (directories up and down),
  - Selection lists accept letter keys to jump to elements,
  - If a text mode menu panel do not fit vertically on the screen, menu items
    are scrolled as needed.
  * New command line options:
  - -txt: force text mode (instead of GUI).
  * General improvements:
  - If a block is selected, actions word_wrap_paragraph, join_paragraph and
    eval_doc act only on it.
  - The internal engine has been partly rewritten, so it requires less memory
    and it's a bit faster.
* Wed Aug 25 2010 detlef@links2linux.de
- new upstream version <5.1.4>
  * If a block is selected, any keystroke substitutes it.
  * Support for Alt + keys (ASCII and movement) has been added,
    and mostly left unbound to be used by the user for his own
    keybindings.
  * A new tab mode, which uses the previous line as a template
    for tab columns.
  * Fixed action `open_under_cursor'.
  * The `mp.paste()' function returns the clipboard content
    as a string if called without arguments.
  * New Grutatxt syntax highlighter.
  * Fix F10 in Win32.
  * Fix a bug when calculating the drawing position in the
    selected block, that were leading to crashes.
* Tue Sep 22 2009 detlef@links2linux.de
- new upstream version <5.1.3>
  * A new Qt4 driver (adapted from the KDE4 driver).
  * A new hexadecimal viewer.
  * New action 'open_dropped_files', to open files dropped from the underlying system GUI.
  * Improved file encoding autodetection by looking at the UTF BOM marks.
  * New configuration option keep_eol, to keep the original end of line sequence each document had.
  * Fixed some clipboard issues, as replacing the selected block when pasting and some crashes.
  * win32 executable has been renamed to mp-5.exe.
  * The status line format string can also include the %%e token to show the encoding used by the document.
  * Fixed win32 input processing in non-latin environments.
  * Setting an empty encoding (to fall back to system defaults) always work.
* Sat Jul 18 2009 detlef@links2linux.de
- new upstream version <5.1.2>
  * The `grep' action can now be recursive.
  * New syntax color for special documentation blocks.
  * Fix searching into empty selected blocks (this was bug #1269).
  * New action `section_list', that shows a list of _sections_
    in the current document to jump to. Sections are usually
    function definitions and special marks in programming
    languages.
  * New action `seek_misspelled', to search the next
    misspelled word. It has been assigned to keycode `f5'.
  * New action `ignore_last_misspell', to add the last misspelled
    word found by `seek_misspelled' to a whitelist so it won't
    be found again.
  * New action `seek_repeated_word', to search for words starting
    or ending with the same number of letters up to a maximum
    distance. It's controlled by the new configuration directives
    `mp.config.rw_num_chars' and `mp.config.rw_max_dist'.
    It has been assigned to keycode `f6' (this keycode was
    previously assigned to `join_paragraph', which has no
    keybinding now).
  * The action `open_templates_file' has been fixed.
  * Several GTK interface updates by fellow developer Sebastian Vöcking.
  * New command line option `-d', to change the working directory.
  * Several fixes to the win32 driver: word wrapping, combobox
    drop-down sizes, underlined text.
  * Avoid hanging if the external ispell program is broken.
  * The `dump()' function now dumps its argument as MPSL code.
* Sun Dec  7 2008 detlef@links2linux.de
- new upstream version <5.1.1>
  * Internationalization works in all platforms (including KDE4,
    were it was faulty, and win32, where it was non-existent since
    the 3.x series).
  * The status line format string can also include the %%w token
    to show the number of words in the current document or selection
    (can be slow).
  * Search and replace is now limited to the selected block, if any.
* Sat Sep 27 2008 detlef@links2linux.de
- new upstream version <5.1.0>
* Wed Jul  2 2008 detlef@links2linux.de
- new upstream version <5.0.3>
* Wed Mar 19 2008 detlef@links2linux.de
- initial build <5.0.2>
